@@ -2,6 +2,8 @@
 #include <Python.h>
 
 struct rndr_state {
+    void *opaque;
+
     struct {
         int header_count;
         int current_level;
@@ -9,10 +11,10 @@ struct rndr_state {
         int nesting_level;
     } toc_data;
 
-    unsigned int flags;
+    hoedown_html_flags flags;
 
     /* extra callbacks */
-    void (*link_attributes)(hoedown_buffer *ob, const hoedown_buffer *url, void *self);
+    void (*link_attributes)(hoedown_buffer *ob, const hoedown_buffer *url, const hoedown_renderer_data *data);
 };
 
 struct renderopt {
